/*
    PEleusis class to play Probabilistic Eleusis.
    
    usage:  java PEleusis ScientistClass distribfile1 distribfile2 ...
    
    example: to test the StupidoScientist with all distributions:
            java PEleusis StupidoScientist ../../data/*
*/

import java.io.*;

public class PEleusis {

    static int maxrounds = 1000000;
    static int initharma = 50;
    
    public static void main(String[] args) throws Exception {
    
        // Find the scientist
        Class sciClass = Class.forName( args[0] );
        
        // initialize variables to do a summary of results
        int[] results = new int[args.length -1];
        int sum = 0;
        
        // loop through the distributions
        for (int i = 1;  i < args.length ; ++i) {
            String distFileName = args[i];
            
            Scientist scientist = (Scientist)sciClass.newInstance();
            
            System.out.print("Distribution " + distFileName+ " ... ");
            System.out.flush();
            
            Distribution distr = new Distribution(
                new BufferedReader( new FileReader(distFileName) ) );
        
            int rounds = 0;
            int harma = initharma;
            for ( ; harma > 0 && rounds < maxrounds; ++rounds) {
            
                Card card = distr.choose();
                Card guess = scientist.guess();
                
                boolean suiteCorrect  = (card.suite  ==  guess.suite);
                boolean numberCorrect = (card.number == guess.number);
                
                scientist.reveal(guess, suiteCorrect, numberCorrect);
                
                harma += (suiteCorrect ? -1 : 1) + (numberCorrect ? -1 : 1);
                if(suiteCorrect && numberCorrect) harma--;
            }
            
            System.out.println("finish in " + rounds + " rounds");
            if (harma > 0) 
                System.out.println(" -> Disqualified, harma left " + harma);
           
            // update the summary variables
            results[i-1] = rounds;
            sum += rounds;
        }
        
        // print the summary
        for (int i = 0; i < results.length -1; ++i) 
            System.out.print(results[i] + " ");
        System.out.println(results[results.length -1]);
        System.out.println(sum);
    }
}    
